@@ -7,7 +7,7 @@
 /**
  * Horde_Data implementation for comma-separated data (CSV).
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -305,7 +305,7 @@ class Horde_Data_Csv extends Horde_Data_Base
      * @return array|boolean  A row from the CSV file or false on error or end
      *                        of file.
      */
-    static public function getCsv($file, array $params = array())
+    public static function getCsv($file, array $params = array())
     {
         $params += array(
             'escape' => '\\',
